summaryrefslogtreecommitdiffstats
path: root/karbon/shapes/vpolyline.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /karbon/shapes/vpolyline.cc
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'karbon/shapes/vpolyline.cc')
-rw-r--r--karbon/shapes/vpolyline.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/karbon/shapes/vpolyline.cc b/karbon/shapes/vpolyline.cc
index 85faa0f7..d716c325 100644
--- a/karbon/shapes/vpolyline.cc
+++ b/karbon/shapes/vpolyline.cc
@@ -30,18 +30,18 @@
#include <KoXmlWriter.h>
#include <KoXmlNS.h>
-VPolyline::VPolyline( VObject* tqparent, VState state )
- : VPath( tqparent, state )
+VPolyline::VPolyline( VObject* parent, VState state )
+ : VPath( parent, state )
{
}
-/*VPolyline::VPolyline( VObject* tqparent, VState state )
- : VPath( tqparent, state )
+/*VPolyline::VPolyline( VObject* parent, VState state )
+ : VPath( parent, state )
{
}*/
-/*VPolyline::VPolyline( VObject* tqparent, const TQString &points )
- : VPath( tqparent ), m_points( points )
+/*VPolyline::VPolyline( VObject* parent, const TQString &points )
+ : VPath( parent ), m_points( points )
{
init();
}*/